pragma solidity ^0.4.0;
pragma experimental ABIEncoderV2;
 
import './ChainDataInterface.sol';
import './ChainDataCmdHelper.sol';
 
// 实现一个 demo 合约
contract BizContract {
    // 账本数据合约
    identity ibc_base_address;
    // 业务 ID 与账本数据访问请求 ID 的关联关系
    mapping(bytes32 => bytes32) requests;
 
    // 权限控制
    modifier onlyIbcBase() {
      require(msg.sender == ibc_base_address, "PERMISSION_ERROR: Permission denied!");
      _;
    }
 
    // 配置账本数据合约 ID
    function setIbcBaseAddress(identity _addr) public  {
        ibc_base_address = _addr;
    }
 
    // 调用账本数据合约的账本数据访问接口访问目标区块链指定一笔交易
    function chainDataRequest(bytes32 biz_id, string domain, bytes block_hash, string path, string parser) public {
 
         // 1. 跨合约调用，需要通过合约接口定义及账本数据合约 ID 生成一个合约对象
        ChainDataInterface ibc = ChainDataInterface(ibc_base_address);
 
        // 2. 拼装账本数据访问命令，拼装区块链头查询命令
        string memory cid = ChainDataCmdHelper.buildMychain010HeaderCID(block_hash);
        string memory cmd = ChainDataCmdHelper.buildCommand(domain, cid, path, parser);

        // 3. 发送账本数据访问请求
        bytes32 request_id = ibc.chainDataRequest(biz_id, cmd, true, this, 0);

        // 4. 记录账本数据合约返回的 request id
        requests[biz_id] = request_id;

        // 5. 请求阶段结束，等待回调
        return;
    }
 
    // 业务合约用于接收账本数据合约的账本数据访问请求结果回调
    function chainDataCallbackResponse (bytes32 _request_id, bytes32 _biz_id, uint32 _error_code, bytes _resp_body, identity _call_identity) onlyIbcBase external returns (bool) {
 
        // 业务处理返回账本数据
        return true;
    }
}
