pragma solidity ^0.4.22;
 
interface ChainDataInterface {
 
    /**
     * function： chainDataRequest
     * usage: 用户合约调用账本数据合约发送跨链账本数据访问请求
     * parameters：
     *         _biz_id            ：用户自定义的业务请求 ID
     *         _chain_data_cmd    ：账本数据访问命令，参考账本数据访问命令说明
     *         _if_callback       ：是否需要账本数据合约将请求结果回调用户合约
     *         _callback_identity ：账本数据合约请求结果回调的合约 ID，可以是发送请求的合约，也可以是其他合约
     *         _delay_time        ：该特性未激活，填 0 即可
     * return value               ：查询请求 ID，是账本数据合约为本次请求生成的唯一请求 ID
     */
    function chainDataRequest(bytes32 _biz_id, string _chain_data_cmd, bool _if_callback, identity _callback_identity, uint256 _delay_time) external returns (bytes32);
 
    /**
     * function: chainDataCallbackResponse
     * usage: 用户合约需要实现的接口，供账本数据合约合约回调
     * parameters:
     *         _request_id       ：账本数据访问请求 ID（在发送账本数据请求时账本数据合约会返回此 ID）
     *         _biz_id           ：用户合约的业务请求 ID
     *         _error_code       ：请求结果码，如果值是 0，则表示预言机请求处理成功；如果是其他值，则为请求处理失败，详见合约错误码表
     *        _resp_body         ：账本数据body
     *        _call_identity     ：发起该请求的合约 ID
     * return value              ：调用结果
     */
    function chainDataCallbackResponse (bytes32 _request_id, bytes32 _biz_id, uint32 _error_code, bytes _resp_body, identity _call_identity) external returns (bool);
}
